@@ -3,8 +3,8 @@
 
 #include <glib-object.h>
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/extensions/contact_sheet/gth-contact-sheet-theme.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/extensions/contact_sheet/gth-contact-sheet-theme.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/extensions/contact_sheet/gth-contact-sheet-theme.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/extensions/contact_sheet/gth-contact-sheet-theme.h"
 GType
 gth_contact_sheet_background_type_get_type (void)
 {
