@@ -3,8 +3,8 @@
 
 #include <glib-object.h>
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/extensions/file_tools/gth-image-rotator.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/extensions/file_tools/gth-image-rotator.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.x86_64/src/gthumb-3.2.9.1/extensions/file_tools/gth-image-rotator.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.x86_64/src/gthumb-3.2.9.1/extensions/file_tools/gth-image-rotator.h"
 GType
 gth_transform_resize_get_type (void)
 {
