@@ -3,8 +3,8 @@
 
 #include <glib-object.h>
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/dom.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/dom.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/dom.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/dom.h"
 GType
 dom_error_enum_get_type (void)
 {
@@ -20,8 +20,8 @@ dom_error_enum_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gio-utils.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gio-utils.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gio-utils.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gio-utils.h"
 GType
 gth_list_flags_get_type (void)
 {
@@ -40,8 +40,8 @@ gth_list_flags_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gnome-desktop-thumbnail.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gnome-desktop-thumbnail.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gnome-desktop-thumbnail.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gnome-desktop-thumbnail.h"
 GType
 gnome_desktop_thumbnail_size_get_type (void)
 {
@@ -57,8 +57,8 @@ gnome_desktop_thumbnail_size_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gsignature.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gsignature.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gsignature.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gsignature.h"
 GType
 g_signature_enc_get_type (void)
 {
@@ -74,8 +74,8 @@ g_signature_enc_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-browser.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-browser.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-browser.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-browser.h"
 GType
 gth_action_get_type (void)
 {
@@ -95,8 +95,8 @@ gth_action_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-color-scale.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-color-scale.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-color-scale.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-color-scale.h"
 GType
 gth_color_scale_type_get_type (void)
 {
@@ -118,8 +118,8 @@ gth_color_scale_type_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-error.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-error.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-error.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-error.h"
 GType
 gth_error_code_get_type (void)
 {
@@ -136,8 +136,8 @@ gth_error_code_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-file-list.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-file-list.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-file-list.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-file-list.h"
 GType
 gth_file_list_mode_get_type (void)
 {
@@ -157,8 +157,8 @@ gth_file_list_mode_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-file-view.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-file-view.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-file-view.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-file-view.h"
 GType
 gth_visibility_get_type (void)
 {
@@ -192,8 +192,8 @@ gth_file_view_renderer_type_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-filter.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-filter.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-filter.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-filter.h"
 GType
 gth_limit_type_get_type (void)
 {
@@ -210,8 +210,8 @@ gth_limit_type_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-grid-view.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-grid-view.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-grid-view.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-grid-view.h"
 GType
 gth_cursor_movement_get_type (void)
 {
@@ -264,8 +264,8 @@ gth_selection_change_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-histogram.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-histogram.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-histogram.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-histogram.h"
 GType
 gth_histogram_channel_get_type (void)
 {
@@ -285,8 +285,8 @@ gth_histogram_channel_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-histogram-view.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-histogram-view.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-histogram-view.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-histogram-view.h"
 GType
 gth_histogram_mode_get_type (void)
 {
@@ -316,8 +316,8 @@ gth_histogram_scale_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-image.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-image.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image.h"
 GType
 gth_image_format_get_type (void)
 {
@@ -335,8 +335,8 @@ gth_image_format_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-image-preloader.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-image-preloader.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-preloader.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-preloader.h"
 GType
 gth_load_policy_get_type (void)
 {
@@ -352,8 +352,8 @@ gth_load_policy_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-image-selector.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-image-selector.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-selector.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-selector.h"
 GType
 gth_selector_type_get_type (void)
 {
@@ -369,8 +369,8 @@ gth_selector_type_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-image-viewer.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-image-viewer.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-viewer.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-image-viewer.h"
 GType
 gth_zoom_quality_get_type (void)
 {
@@ -467,8 +467,8 @@ gth_check_size_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-metadata.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-metadata.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-metadata.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-metadata.h"
 GType
 gth_metadata_type_get_type (void)
 {
@@ -500,8 +500,8 @@ gth_metadata_flags_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-metadata-provider.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-metadata-provider.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-metadata-provider.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-metadata-provider.h"
 GType
 gth_metadata_write_flags_get_type (void)
 {
@@ -517,8 +517,8 @@ gth_metadata_write_flags_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-monitor.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-monitor.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-monitor.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-monitor.h"
 GType
 gth_monitor_event_get_type (void)
 {
@@ -536,8 +536,8 @@ gth_monitor_event_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-overwrite-dialog.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-overwrite-dialog.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-overwrite-dialog.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-overwrite-dialog.h"
 GType
 gth_overwrite_response_get_type (void)
 {
@@ -558,8 +558,8 @@ gth_overwrite_response_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-sidebar.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-sidebar.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-sidebar.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-sidebar.h"
 GType
 gth_sidebar_state_get_type (void)
 {
@@ -576,8 +576,8 @@ gth_sidebar_state_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-task.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-task.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-task.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-task.h"
 GType
 gth_task_error_enum_get_type (void)
 {
@@ -594,8 +594,8 @@ gth_task_error_enum_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-test.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-test.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test.h"
 GType
 gth_match_get_type (void)
 {
@@ -636,8 +636,8 @@ gth_test_op_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-test-chain.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-test-chain.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test-chain.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test-chain.h"
 GType
 gth_match_type_get_type (void)
 {
@@ -654,8 +654,8 @@ gth_match_type_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-test-simple.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-test-simple.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test-simple.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-test-simple.h"
 GType
 gth_test_data_type_get_type (void)
 {
@@ -674,8 +674,8 @@ gth_test_data_type_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-user-dir.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gth-user-dir.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-user-dir.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gth-user-dir.h"
 GType
 gth_dir_get_type (void)
 {
@@ -692,8 +692,8 @@ gth_dir_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gtk-utils.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/gtk-utils.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gtk-utils.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/gtk-utils.h"
 GType
 gth_action_flags_get_type (void)
 {
@@ -710,8 +710,8 @@ gth_action_flags_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/pixbuf-cache.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/pixbuf-cache.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/pixbuf-cache.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/pixbuf-cache.h"
 GType
 pixbuf_cache_channel_get_type (void)
 {
@@ -731,8 +731,8 @@ pixbuf_cache_channel_get_type (void)
   return etype;
 }
 
-/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/typedefs.h" */
-#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-3.x86_64/src/gthumb-3.2.9.1/gthumb/typedefs.h"
+/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/typedefs.h" */
+#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.i686/src/gthumb-3.2.9.1/gthumb/typedefs.h"
 GType
 gth_click_policy_get_type (void)
 {
